.. _mendeleev:

====================================
Welcome to mendeleev's documentation
====================================

This package provides an API for accessing various properties of elements from
the periodic table of elements.

.. image:: img/periodictable.png
    :width: 800px
    :align: center
    :alt: alternate text


Contents
========

.. toctree::
   :maxdepth: 2

   Data <data>
   Installation <install>
   Tutorials <tutorials>
   Electronegativity <electronegativity>
   API Reference <_reference/modules>
   License <license_link>


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
